@@ -238,3 +238,39 @@ class MVPoly(object) :
         """
         from mvpoly.cube import MVPolyCube
         return cls(MVPolyCube.rudin_shapiro(n, **kwargs), **kwargs)
+
+
+# this code imports all of the 1d orthogonal polynomials from
+# the scipy.special collection with a bit of metaprogramming
+
+import scipy.special
+
+def add_scipy_special(cls, name, meth) :
+    def special(cls, *args) :
+        from mvpoly.cube import MVPolyCube
+        coef = meth(*args).coeffs
+        p = MVPolyCube(coef[::-1])
+        if cls == MVPolyCube :
+            return p
+        else :
+            return cls(p)
+    special.__name__ = name
+    special.__doc__ = "Wrapper around :meth:`scipi.special.%s`" % (name)
+    setattr(MVPoly, special.__name__, classmethod(special))
+
+for name, meth in [ ('legendre',    scipy.special.legendre), 
+                    ('chebyt',      scipy.special.chebyt),
+                    ('chebyu',      scipy.special.chebyu),
+                    ('chebyc',      scipy.special.chebyc),
+                    ('chebys',      scipy.special.chebys),
+                    ('jacobi',      scipy.special.jacobi),
+                    ('laguerre',    scipy.special.laguerre),
+                    ('genlaguerre', scipy.special.genlaguerre),
+                    ('hermite',     scipy.special.hermite),
+                    ('hermitenorm', scipy.special.hermitenorm),
+                    ('gegenbauer',  scipy.special.gegenbauer),
+                    ('sh_legendre', scipy.special.sh_legendre),
+                    ('sh_chebyt',   scipy.special.sh_chebyt),
+                    ('sh_chebyu',   scipy.special.sh_chebyu),
+                    ('sh_jacobi',   scipy.special.sh_jacobi) ] :
+    add_scipy_special(MVPoly, name, meth)
