@@ -423,10 +423,10 @@ class MVPolyDict(mvpoly.base.MVPoly) :
 
 
     @classmethod
-    def berenstein(cls, i, n, **kwd) :
+    def bernstein(cls, i, n, **kwd) :
         """
         Return the degree *n*
-        `Berenstein polynomial <http://www.encyclopediaofmath.org/index.php/Bernstein_polynomials>`_ 
+        `Bernstein polynomial <http://www.encyclopediaofmath.org/index.php/Bernstein_polynomials>`_ 
         of the specified index *i*. Both *n* and *i* may
         be lists or tuples of non-negative numbers of the
         same size and with *i* dominated by *n*.
