@@ -20,6 +20,18 @@ def max_or_default(iterable, default) :
     except ValueError :
         return default
 
+def binom(n, r) :
+    """
+    Returns the binomial coefficient as a long integer.
+    """
+    assert n >= 0
+    assert 0 <= r <= n
+    c = 1L
+    denom = 1
+    for (num,denom) in zip(xrange(n,n-r,-1), xrange(1,r+1,1)):
+        c = (c * num) // denom
+    return c
+
 def as_numpy_scalar(x) :
     """
     Returns a :class:`numpy` scalar.
