@@ -738,3 +738,42 @@ class TestMVPolyBernstein(unittest.TestCase) :
             for dt in [int, float, np.double] :
                 p = C.bernstein((3,2), (5,7), dtype=dt)
                 self.assertTrue(p.dtype == dt, "rudin-shapiro dtype")
+
+class TestMVPolySpecial(unittest.TestCase) :
+
+    # we test a selection of the scipy.special polys, checking
+    # that they agree with the classical defunition
+
+    def test_legendre_size(self) :
+        for C in classes :
+            for n in range(1, 10) :
+                p = C.legendre(n)
+                self.assertTrue(p.degrees == (n,), 
+                                "legendre degree %i" % (n))
+
+    def test_legendre_explicit(self) :
+        for C in classes :
+            x, = C.monomials(1)
+            p = C.legendre(5)
+            q = (63*x**5 - 70*x**3 + 15*x)*(1./8)
+            self.assertTrue((p - q).norm(np.inf) < 1e-10 , 
+                            "legendre explicit")
+
+    def test_hermitenorm_explicit(self) :
+        for C in classes :
+            x, = C.monomials(1)
+            p = C.hermitenorm(5)
+            q = x**5 - 10*x**3 + 15*x
+            self.assertTrue((p - q).norm(np.inf) < 1e-10 , 
+                            "hermitenorm explicit")
+
+    def test_laguerre_explicit(self) :
+        for C in classes :
+            x, = C.monomials(1)
+            p = C.laguerre(3)
+            q = (1./6)*(-x**3 + 9*x**2 - 18*x + 6)
+            self.assertTrue((p - q).norm(np.inf) < 1e-10 , 
+                            "laguerre explicit")
+
+
+
